@@ -1,5 +1,5 @@
-version = "1.0.0"
-image_dir = "/usr/local/share/pixmaps"
+version = "2.0.2"
+image_dir = "/usr/local/share/pixmaps/gnome-schedule"
 glade_dir = "/usr/local/share/gnome-schedule"
 locale_dir = "/usr/local/share/locale"
 crontabbin = "/usr/bin/crontab"
